@@ -248,6 +248,19 @@ int FillFptrTable() {
   FptrTableV5["decay_time_constant_after_stim"] =
       &LibV5::decay_time_constant_after_stim;
 
+  FptrTableV5["ohmic_input_resistance_vb_ssse"] =
+      &LibV5::ohmic_input_resistance_vb_ssse;
+  FptrTableV5["voltage_deflection_vb_ssse"] =
+      &LibV5::voltage_deflection_vb_ssse;
+  FptrTableV5["maximum_voltage_from_voltagebase"] =
+      &LibV5::maximum_voltage_from_voltagebase;
+  FptrTableV5["Spikecount_stimint"] = &LibV5::Spikecount_stimint;
+  
+  FptrTableV5["peak_indices"] = &LibV5::peak_indices;
+  FptrTableV5["sag_amplitude"] = &LibV5::sag_amplitude;
+  FptrTableV5["sag_ratio1"] = &LibV5::sag_ratio1;
+  FptrTableV5["sag_ratio2"] = &LibV5::sag_ratio2;
+  
   //****************** end of FptrTableV5 *****************************
 
   return 1;
