@@ -202,5 +202,29 @@ int voltage_base(mapStr2intVec& IntFeatureData,
 int decay_time_constant_after_stim(mapStr2intVec& IntFeatureData,
                                    mapStr2doubleVec& DoubleFeatureData,
                                    mapStr2Str& StringData);
+int voltage_deflection_vb_ssse(mapStr2intVec& IntFeatureData,
+                                   mapStr2doubleVec& DoubleFeatureData,
+                                   mapStr2Str& StringData);
+int ohmic_input_resistance_vb_ssse(mapStr2intVec& IntFeatureData,
+                                   mapStr2doubleVec& DoubleFeatureData,
+                                   mapStr2Str& StringData);
+int maximum_voltage_from_voltagebase(mapStr2intVec& IntFeatureData,
+                                   mapStr2doubleVec& DoubleFeatureData,
+                                   mapStr2Str& StringData);
+int Spikecount_stimint(mapStr2intVec& IntFeatureData,                                    
+                       mapStr2doubleVec& DoubleFeatureData, 
+                       mapStr2Str& StringData); 
+int peak_indices(mapStr2intVec& IntFeatureData,                                    
+                       mapStr2doubleVec& DoubleFeatureData, 
+                       mapStr2Str& StringData); 
+int sag_amplitude(mapStr2intVec& IntFeatureData,                                    
+                       mapStr2doubleVec& DoubleFeatureData, 
+                       mapStr2Str& StringData); 
+int sag_ratio1(mapStr2intVec& IntFeatureData,                                    
+                       mapStr2doubleVec& DoubleFeatureData, 
+                       mapStr2Str& StringData); 
+int sag_ratio2(mapStr2intVec& IntFeatureData,                                    
+                       mapStr2doubleVec& DoubleFeatureData, 
+                       mapStr2Str& StringData); 
 }
 #endif
