@@ -96,7 +96,9 @@ void cFeature::fillfeaturetypes() {
   featuretypes["AHP_depth_abs"] = "double";
   featuretypes["time_constant"] = "double";
   featuretypes["voltage_deflection"] = "double";
+  featuretypes["voltage_deflection_vb_ssse"] = "double";
   featuretypes["ohmic_input_resistance"] = "double";
+  featuretypes["ohmic_input_resistance_vb_ssse"] = "double";
   featuretypes["maximum_voltage"] = "double";
   featuretypes["minimum_voltage"] = "double";
   featuretypes["steady_state_voltage"] = "double";
@@ -161,6 +163,7 @@ void cFeature::fillfeaturetypes() {
   featuretypes["AHP_depth_abs_slow"] = "double";
   featuretypes["AHP_slow_time"] = "double";
   featuretypes["Spikecount"] = "int";
+  featuretypes["Spikecount_stimint"] = "int";
   featuretypes["AHP_depth"] = "double";
   featuretypes["amp_drop_first_second"] = "double";
   featuretypes["amp_drop_first_last"] = "double";
@@ -233,6 +236,10 @@ void cFeature::fillfeaturetypes() {
   featuretypes["steady_state_voltage_stimend"] = "double";
   featuretypes["voltage_base"] = "double";
   featuretypes["decay_time_constant_after_stim"] = "double";
+  featuretypes["maximum_voltage_from_voltagebase"] = "double";
+  featuretypes["sag_amplitude"] = "double";
+  featuretypes["sag_ratio1"] = "double";
+  featuretypes["sag_ratio2"] = "double";
 
   // end of feature types
 }
@@ -527,7 +534,8 @@ int cFeature::printFeature(const char* strFileName) {
   return 1;
 }
 
-double cFeature::getDistance(string strName, double mean, double std) {
+double cFeature::getDistance(string strName, double mean, double std, 
+        bool trace_check) {
 
   vector<double> feature_vec;
   vector<int> feature_veci;
@@ -537,10 +545,11 @@ double cFeature::getDistance(string strName, double mean, double std) {
 
   // Check if a the trace doesn't contain any spikes outside of the stimulus
   // interval
-  retVal = getFeatureInt("trace_check", feature_veci);
-  if (retVal < 0) {
-    // printf("Warning: Trace check failed");
-    return 250.0;
+  if (trace_check) {
+      retVal = getFeatureInt("trace_check", feature_veci);
+      if (retVal < 0) {
+          return 250.0;
+      }
   }
 
   // check datatype of feature
